@@ -25,7 +25,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_docdb.type_defs import (
     DBClusterMessageTypeDef,
@@ -56,7 +56,7 @@ __all__ = (
 
 class DescribeDBClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
+    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
     """
 
     def paginate(
@@ -64,15 +64,15 @@ class DescribeDBClustersPaginator(Boto3Paginator):
         DBClusterIdentifier: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBClusterMessageTypeDef, None, None]:
+    ) -> Iterator[DBClusterMessageTypeDef]:
         """
-        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters.paginate)
+        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters.paginate)
         """
 
 
 class DescribeDBEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
+    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
     """
 
     def paginate(
@@ -85,15 +85,15 @@ class DescribeDBEngineVersionsPaginator(Boto3Paginator):
         ListSupportedCharacterSets: bool = None,
         ListSupportedTimezones: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBEngineVersionMessageTypeDef, None, None]:
+    ) -> Iterator[DBEngineVersionMessageTypeDef]:
         """
-        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions.paginate)
+        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions.paginate)
         """
 
 
 class DescribeDBInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
+    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
     """
 
     def paginate(
@@ -101,15 +101,15 @@ class DescribeDBInstancesPaginator(Boto3Paginator):
         DBInstanceIdentifier: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBInstanceMessageTypeDef, None, None]:
+    ) -> Iterator[DBInstanceMessageTypeDef]:
         """
-        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances.paginate)
+        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances.paginate)
         """
 
 
 class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
     """
 
     def paginate(
@@ -117,15 +117,15 @@ class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
         DBSubnetGroupName: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBSubnetGroupMessageTypeDef, None, None]:
+    ) -> Iterator[DBSubnetGroupMessageTypeDef]:
         """
-        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups.paginate)
+        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups.paginate)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
+    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
     """
 
     def paginate(
@@ -145,15 +145,15 @@ class DescribeEventsPaginator(Boto3Paginator):
         EventCategories: List[str] = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[EventsMessageTypeDef, None, None]:
+    ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeEvents.paginate)
+        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeEvents.paginate)
         """
 
 
 class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
+    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
     """
 
     def paginate(
@@ -165,7 +165,7 @@ class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
         Vpc: bool = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[OrderableDBInstanceOptionsMessageTypeDef, None, None]:
+    ) -> Iterator[OrderableDBInstanceOptionsMessageTypeDef]:
         """
-        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions.paginate)
+        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions.paginate)
         """
